EXPORTS
	__13CSmsTestUtilsR5RTest @ 1 NONAME ; CSmsTestUtils::CSmsTestUtils(RTest &)
	AddSystemAgentConditionsL__13CSmsTestUtils @ 2 NONAME ; CSmsTestUtils::AddSystemAgentConditionsL(void)
	AreMessagesSameTextL__13CSmsTestUtilslli @ 3 NONAME ; CSmsTestUtils::AreMessagesSameTextL(long, long, int)
	ClearLogL__12CSmsTestBase @ 4 NONAME ; CSmsTestBase::ClearLogL(void)
	ConstructL__13CSmsTestUtilsUi @ 5 NONAME ; CSmsTestUtils::ConstructL(unsigned int)
	CreateDummyMessageToReceiveL__13CSmsTestUtils @ 6 NONAME ; CSmsTestUtils::CreateDummyMessageToReceiveL(void)
	CreateDummyMessageToSendL__13CSmsTestUtils @ 7 NONAME ; CSmsTestUtils::CreateDummyMessageToSendL(void)
	CreateMessageL__13CSmsTestUtilslR9TMsvEntryR10CSmsHeaderR9CRichTextRC5TTime @ 8 NONAME ; CSmsTestUtils::CreateMessageL(long, TMsvEntry &, CSmsHeader &, CRichText &, TTime const &)
	CreateSmsServerMtmRegL__13CSmsTestUtils @ 9 NONAME ; CSmsTestUtils::CreateSmsServerMtmRegL(void)
	CreateSmsServiceL__13CSmsTestUtils @ 10 NONAME ; CSmsTestUtils::CreateSmsServiceL(void)
	DeleteSmsMessagesL__13CSmsTestUtilsl @ 11 NONAME ; CSmsTestUtils::DeleteSmsMessagesL(long)
	DeleteSmsServiceL__13CSmsTestUtils @ 12 NONAME ; CSmsTestUtils::DeleteSmsServiceL(void)
	DisplayLogL__12CSmsTestBase @ 13 NONAME ; CSmsTestBase::DisplayLogL(void)
	DisplayMessageL__13CSmsTestUtilsl @ 14 NONAME ; CSmsTestUtils::DisplayMessageL(long)
	DisplayMessagesL__13CSmsTestUtilsRC18CMsvEntrySelection @ 15 NONAME ; CSmsTestUtils::DisplayMessagesL(CMsvEntrySelection const &)
	DisplaySendingStatesL__13CSmsTestUtilsRC18CMsvEntrySelection @ 16 NONAME ; CSmsTestUtils::DisplaySendingStatesL(CMsvEntrySelection const &)
	DoTestSchedulingL__12CSmsTestBaseRC7TDesC16iG20TTimeIntervalSeconds @ 17 NONAME ; CSmsTestBase::DoTestSchedulingL(TDesC16 const &, int, TTimeIntervalSeconds)
	DoTestSendingL__12CSmsTestBaseRC7TDesC16i @ 18 NONAME ; CSmsTestBase::DoTestSendingL(TDesC16 const &, int)
	FindExistingServicesL__13CSmsTestUtils @ 19 NONAME ; CSmsTestUtils::FindExistingServicesL(void)
	FindExistingSmsServiceL__13CSmsTestUtils @ 20 NONAME ; CSmsTestUtils::FindExistingSmsServiceL(void)
	GetHeaderLC__13CSmsTestUtilsl @ 21 NONAME ; CSmsTestUtils::GetHeaderLC(long)
	InstallSmsMtmGroupL__13CSmsTestUtils @ 22 NONAME ; CSmsTestUtils::InstallSmsMtmGroupL(void)
	InstantiateSmsClientMtmL__13CSmsTestUtils @ 23 NONAME ; CSmsTestUtils::InstantiateSmsClientMtmL(void)
	InstantiateSmsServerMtmL__13CSmsTestUtils @ 24 NONAME ; CSmsTestUtils::InstantiateSmsServerMtmL(void)
	NewLC__13CSmsTestUtilsR5RTestUi @ 25 NONAME ; CSmsTestUtils::NewLC(RTest &, unsigned int)
	NewL__13CSmsTestUtilsR5RTestUi @ 26 NONAME ; CSmsTestUtils::NewL(RTest &, unsigned int)
	Panic__13CSmsTestUtils18TSmsTestUtilsPanic @ 27 NONAME ; CSmsTestUtils::Panic(TSmsTestUtilsPanic)
	Panic__13CSmsTestUtilsi @ 28 NONAME ; CSmsTestUtils::Panic(int)
	ReadScriptL__13CSmsTestUtilsRC7TDesC16lR18CMsvEntrySelectionRC5TTime @ 29 NONAME ; CSmsTestUtils::ReadScriptL(TDesC16 const &, long, CMsvEntrySelection &, TTime const &)
	RunError__12CSmsTestBasei @ 30 NONAME ; CSmsTestBase::RunError(int)
	SaveBodyToFileL__13CSmsTestUtilsl @ 31 NONAME ; CSmsTestUtils::SaveBodyToFileL(long)
	SendingCompleteL__13CSmsTestUtilsRC18CMsvEntrySelectionRi @ 32 NONAME ; CSmsTestUtils::SendingCompleteL(CMsvEntrySelection const &, int &)
	SetCommDbServiceCenterFromScriptL__13CSmsTestUtilsRC7TDesC16 @ 33 NONAME ; CSmsTestUtils::SetCommDbServiceCenterFromScriptL(TDesC16 const &)
	StartL__12CSmsTestBase @ 34 NONAME ; CSmsTestBase::StartL(void)
	"_._12CSmsTestBase" @ 35 NONAME ; CSmsTestBase::~CSmsTestBase(void)
	"_._13CSmsTestUtils" @ 36 NONAME ; CSmsTestUtils::~CSmsTestUtils(void)
	__12CSmsTestBaseR13CSmsTestUtilsRC7TDesC16Rii @ 37 NONAME ; CSmsTestBase::CSmsTestBase(CSmsTestUtils &, TDesC16 const &, int &, int)
	AddRecipientL__13CSmsTestUtilslRC7TDesC16 @ 38 NONAME ; CSmsTestUtils::AddRecipientL(long, TDesC16 const &)
	DoTestForwardMsgL__12CSmsTestBasel @ 39 NONAME ; CSmsTestBase::DoTestForwardMsgL(long)
	DoTestSendMesssageL__12CSmsTestBasel @ 40 NONAME ; CSmsTestBase::DoTestSendMesssageL(long)
	NotifySaPhoneOnL__13CSmsTestUtils @ 41 NONAME ; CSmsTestUtils::NotifySaPhoneOnL(void)
	WaitForInitializeL__13CSmsTestUtils @ 42 NONAME R3UNUSED ; CSmsTestUtils::WaitForInitializeL(void)
	NotifySaPhoneOffL__13CSmsTestUtils @ 43 NONAME R3UNUSED ; CSmsTestUtils::NotifySaPhoneOffL(void)
	CompareEmsIE__12EmsTestUtilsRC22CEmsInformationElementT1 @ 44 NONAME R3UNUSED ; EmsTestUtils::CompareEmsIE(CEmsInformationElement const &, CEmsInformationElement const &)
	CompareEmsMsgL__12EmsTestUtilsRC11CSmsMessageT1 @ 45 NONAME R3UNUSED ; EmsTestUtils::CompareEmsMsgL(CSmsMessage const &, CSmsMessage const &)
	CreateAnimationL__12EmsTestUtilsi @ 46 NONAME R3UNUSED ; EmsTestUtils::CreateAnimationL(int)
	CreatePictureL__12EmsTestUtilsi @ 47 NONAME R3UNUSED ; EmsTestUtils::CreatePictureL(int)
	FindElementL__12EmsTestUtilsRC11CSmsMessageQ222CSmsInformationElement32TSmsInformationElementIdentifier @ 48 NONAME R3UNUSED ; EmsTestUtils::FindElementL(CSmsMessage const &, CSmsInformationElement::TSmsInformationElementIdentifier)

